#ifndef NT2_INCLUDE_FUNCTIONS_ISEQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISEQUAL_HPP_INCLUDED

#include <nt2/predicates/include/functions/isequal.hpp>

#endif
